==> jc-1.4.0.tar.gz: ppg/code/ActionCode.h <==
// public class ppg.code.ActionCode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4dec6bdf8ce44fa ppg_code_ActionCode
// @dep_class ff40332975ef3bc9 ppg_code_Code

// header file dependencies
// @dep_header ppg_code_Code

#include "ppg/code/Code.h"

#ifndef _JC_ppg_code_ActionCode_H_
#define _JC_ppg_code_ActionCode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_code_ActionCode$sub_refs	_jc_ppg_code_ActionCode$sub_refs;
typedef struct _jc_ppg_code_ActionCode$sub_nonrefs	_jc_ppg_code_ActionCode$sub_nonrefs;
typedef struct _jc_ppg_code_ActionCode$refs	_jc_ppg_code_ActionCode$refs;
typedef struct _jc_ppg_code_ActionCode$nonrefs	_jc_ppg_code_ActionCode$nonrefs;
typedef struct _jc_ppg_code_ActionCode$object	_jc_ppg_code_ActionCode$object;

typedef const struct _jc_ppg_code_ActionCode$vmethods	_jc_ppg_code_ActionCode$vmethods;
typedef const struct _jc_ppg_code_ActionCode$vtable	_jc_ppg_code_ActionCode$vtable;
typedef const struct _jc_ppg_code_ActionCode$vtype	_jc_ppg_code_ActionCode$vtype;

// Constructors
extern void _jc_ppg_code_ActionCode$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_code_ActionCode$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_code_ActionCode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_code_ActionCode$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_code_ActionCode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_code_ActionCode$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_code_ActionCode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_code_ActionCode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_code_ActionCode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_code_ActionCode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_code_ActionCode$object *);
};

// Vtable
struct _jc_ppg_code_ActionCode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_code_Code$vmethods	ppg_code_Code;
	_jc_ppg_code_ActionCode$vmethods	ppg_code_ActionCode;
};

// Vtype
struct _jc_ppg_code_ActionCode$vtype {
	_jc_type			type;
	_jc_ppg_code_ActionCode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_code_ActionCode$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_code_ActionCode$refs {
    _jc_ppg_code_ActionCode$sub_refs	ppg_code_ActionCode;
    _jc_ppg_code_Code$sub_refs	ppg_code_Code;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_code_ActionCode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_code_ActionCode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_code_Code$sub_nonrefs	ppg_code_Code;
    _jc_ppg_code_ActionCode$sub_nonrefs	ppg_code_ActionCode;
};

// Object instance structure
struct _jc_ppg_code_ActionCode$object {
	_jc_ppg_code_ActionCode$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_code_ActionCode$vtype	*vtype;
	_jc_ppg_code_ActionCode$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_code_ActionCode$vtype _jc_ppg_code_ActionCode$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_code_ActionCode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_code_ActionCode$class_object;

#endif	/* _JC_ppg_code_ActionCode_H_ */

==> jc-1.4.6.tar.gz: ppg/code/ActionCode.h <==
// public class ppg.code.ActionCode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4dec6bdf8ce44fa ppg_code_ActionCode
// @dep_class ff40332975ef3bc9 ppg_code_Code

// header file dependencies
// @dep_header ppg_code_Code

#include "ppg/code/Code.h"

#ifndef _JC_ppg_code_ActionCode_H_
#define _JC_ppg_code_ActionCode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_code_ActionCode$sub_refs	_jc_ppg_code_ActionCode$sub_refs;
typedef struct _jc_ppg_code_ActionCode$sub_nonrefs	_jc_ppg_code_ActionCode$sub_nonrefs;
typedef struct _jc_ppg_code_ActionCode$refs	_jc_ppg_code_ActionCode$refs;
typedef struct _jc_ppg_code_ActionCode$nonrefs	_jc_ppg_code_ActionCode$nonrefs;
typedef struct _jc_ppg_code_ActionCode$object	_jc_ppg_code_ActionCode$object;

typedef const struct _jc_ppg_code_ActionCode$vmethods	_jc_ppg_code_ActionCode$vmethods;
typedef const struct _jc_ppg_code_ActionCode$vtable	_jc_ppg_code_ActionCode$vtable;
typedef const struct _jc_ppg_code_ActionCode$vtype	_jc_ppg_code_ActionCode$vtype;

// Constructors
extern void _jc_ppg_code_ActionCode$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_code_ActionCode$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_code_ActionCode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_code_ActionCode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_code_ActionCode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_code_ActionCode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_code_ActionCode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_code_ActionCode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_code_ActionCode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_code_ActionCode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_code_ActionCode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_code_ActionCode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_code_Code$vmethods	ppg_code_Code;
	_jc_ppg_code_ActionCode$vmethods	ppg_code_ActionCode;
};

// Vtype
struct _jc_ppg_code_ActionCode$vtype {
	_jc_type			type;
	_jc_ppg_code_ActionCode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_code_ActionCode$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_code_ActionCode$refs {
    _jc_ppg_code_ActionCode$sub_refs	ppg_code_ActionCode;
    _jc_ppg_code_Code$sub_refs	ppg_code_Code;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_code_ActionCode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_code_ActionCode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_code_Code$sub_nonrefs	ppg_code_Code;
    _jc_ppg_code_ActionCode$sub_nonrefs	ppg_code_ActionCode;
};

// Object instance structure
struct _jc_ppg_code_ActionCode$object {
	_jc_ppg_code_ActionCode$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_code_ActionCode$vtype	*vtype;
	_jc_ppg_code_ActionCode$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_code_ActionCode$vtype _jc_ppg_code_ActionCode$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_code_ActionCode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_code_ActionCode$class_object;

#endif	/* _JC_ppg_code_ActionCode_H_ */
